==> hsqldb_2.6.1.orig.tar.xz: hsqldb-2.6.1/hsqldb/src/org/hsqldb/types/ClobData.java <==
/* Copyright (c) 2001-2021, The HSQL Development Group
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name of the HSQL Development Group nor the names of its
 * contributors may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL HSQL DEVELOPMENT GROUP, HSQLDB.ORG,
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


package org.hsqldb.types;

import java.io.Reader;

import org.hsqldb.SessionInterface;

/**
 * Interface for Character Large Object implementations.<p>
 *
 * @author Fred Toussi (fredt@users dot sourceforge.net)
 * @version 1.9.0
 * @since 1.9.0
 */
public interface ClobData extends LobData {

    char[] getChars(SessionInterface session, final long position, int length);

    long length(SessionInterface session);

    String getSubString(SessionInterface session, final long pos,
                        final int length);

    ClobData getClob(SessionInterface session, final long pos,
                     final long length);

    ClobData duplicate(SessionInterface session);

    void truncate(SessionInterface session, long len);

    Reader getCharacterStream(SessionInterface session);

    void setString(SessionInterface session, long pos, String str);

    void setClob(SessionInterface session, long pos, ClobData clob, long offset,
                  long len);

    void setChars(SessionInterface session, long pos, char[] chars, int offset,
                 int len);

    void setCharacterStream(SessionInterface session, long pos,
                                   Reader in);

    long position(SessionInterface session, String searchstr, long start);

    long position(SessionInterface session, ClobData searchstr, long start);

    long nonSpaceLength(SessionInterface session);

    Reader getCharacterStream(SessionInterface session, long pos, long length);

    long getId();

    void setId(long id);
}

==> hsqldb_2.7.1.orig.tar.xz: hsqldb-2.7.1/hsqldb/src/org/hsqldb/types/ClobData.java <==
/* Copyright (c) 2001-2022, The HSQL Development Group
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * Neither the name of the HSQL Development Group nor the names of its
 * contributors may be used to endorse or promote products derived from this
 * software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL HSQL DEVELOPMENT GROUP, HSQLDB.ORG,
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */


package org.hsqldb.types;

import java.io.Reader;

import org.hsqldb.SessionInterface;

/**
 * Interface for Character Large Object implementations.<p>
 *
 * @author Fred Toussi (fredt@users dot sourceforge.net)
 * @version 1.9.0
 * @since 1.9.0
 */
public interface ClobData extends LobData {

    char[] getChars(SessionInterface session, final long position, int length);

    long length(SessionInterface session);

    String getSubString(SessionInterface session, final long pos,
                        final int length);

    ClobData getClob(SessionInterface session, final long pos,
                     final long length);

    ClobData duplicate(SessionInterface session);

    void truncate(SessionInterface session, long len);

    Reader getCharacterStream(SessionInterface session);

    void setString(SessionInterface session, long pos, String str);

    void setClob(SessionInterface session, long pos, ClobData clob,
                 long offset, long len);

    void setChars(SessionInterface session, long pos, char[] chars,
                  int offset, int len);

    void setCharacterStream(SessionInterface session, long pos, Reader in);

    long position(SessionInterface session, String searchstr, long start);

    long position(SessionInterface session, ClobData searchstr, long start);

    long nonSpaceLength(SessionInterface session);

    Reader getCharacterStream(SessionInterface session, long pos, long length);

    long getId();

    void setId(long id);
}
